.. image:: https://img.shields.io/pypi/v/zope.app.server.svg
        :target: https://pypi.python.org/pypi/zope.app.server/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.app.server.svg
        :target: https://pypi.org/project/zope.app.server/
        :alt: Supported Python versions

.. image:: https://travis-ci.com/zopefoundation/zope.app.server.svg?branch=master
        :target: https://travis-ci.com/zopefoundation/zope.app.server

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.app.server/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.app.server?branch=master


This package integrates ZServer -- Zope's HTTP and FTP server -- into a Zope 3
application setup. It also defines the script skeleton for a classic Zope 3
application.
